@@ -26,7 +26,7 @@ from dicompyler import dicomgui, dvhdata, dvhdoses, dvhcalc
 from dicompyler.dicomparser import DicomParser as dp
 from dicompyler import plugin, preferences
 
-__version__ = "0.4.1"
+__version__ = "0.4.1-1"
 
 class MainFrame(wx.Frame):
     def __init__(self, parent, id, title, res):
@@ -54,7 +54,7 @@ class MainFrame(wx.Frame):
         # Add file logger
         logpath = os.path.join(guiutil.get_data_dir(), 'logs')
         if not os.path.exists(logpath):
-            os.mkdir(logpath)
+            os.makedirs(logpath)
         self.fh = logging.handlers.RotatingFileHandler(
                 os.path.join(logpath, 'dicompyler.log'),
                 maxBytes=524288, backupCount=7)
